@@ -20,13 +20,13 @@ project = 'BirdBrain-Python-Library'
 year = '2022'
 author = 'Frank Morton'
 copyright = '{0}, {1}'.format(year, author)
-version = release = '0.0.8'
+version = release = '0.0.11'
 
 pygments_style = 'trac'
 templates_path = ['.']
 extlinks = {
-    'issue': ('https://github.com/fmorton/BirdBrain-Python-Library/issues/%s', '#'),
-    'pr': ('https://github.com/fmorton/BirdBrain-Python-Library/pull/%s', 'PR #'),
+    'issue': ('https://github.com/fmorton/BirdBrain-Python-Library/issues/%s', 'issue #%s'),
+    'pr': ('https://github.com/fmorton/BirdBrain-Python-Library/pull/%s', 'PR #%s'),
 }
 # on_rtd is whether we are on readthedocs.org
 on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
